@@ -3,7 +3,7 @@ from bruhanimate.bruheffects    import BaseEffect, StaticEffect, OffsetEffect, N
 from bruhanimate.bruhffer       import Buffer
 from bruhanimate.bruhrenderer   import BaseRenderer, EffectRenderer, CenterRenderer, PanRenderer, FocusRenderer
 from bruhanimate import images
-from bruhanimate.demos import demo, line_demo
+from bruhanimate import demo, line_demo
 
 
 
