@@ -248,7 +248,7 @@ class PlasmaEffect(BaseEffect):
         :param random_color: True / False to generate random colors
         """
         self.color = color
-        self.random = True
+        self.random = random_color
         if not random_color:
             self.colors = _PLASMA_COLORS[len(self.scale)][0]
         else:
